const MiniCssExtractPlugin = require('mini-css-extract-plugin')
const autoprefixer = require('autoprefixer')
const pxtorem = require('postcss-pxtorem')

function getLoader(mode = "development") {
    const all_loader = [
        {
            mode: 'all',
            name: 'vue-loader',
            loader: {
                test: /\.vue$/,
                loader: 'vue-loader'
            },
            desc: ""
        },
        {
            mode: 'all',
            name: 'babel-loader',
            loader: {
                test: /\.(js)$/,
                exclude: /node_modules/,
                loader: 'babel-loader',
                options: {
                    "plugins": [
                        "@babel/plugin-transform-runtime",
                        "@babel/plugin-proposal-class-properties",
                        "@babel/plugin-syntax-dynamic-import",
                        "@babel/plugin-proposal-object-rest-spread",
                        ["import", {
                            "libraryName": "vant",
                            "libraryDirectory": "es",
                            "style": true
                          }]
                    ],
                    "presets": [
                        "@babel/preset-env"
                    ]
                }
            },
            desc: ''
        },
        {
            mode: 'all',
            name: 'scss-loader',
            loader: {
                test: /\.scss/,
                loaders: [
                    mode === 'development' ? 'vue-style-loader' : {
                        loader: MiniCssExtractPlugin.loader,
                        options: {
                            reloadAll: true,
                        },
                    },
                    {
                        loader: 'css-loader',
                        options: {
                            importLoaders: 1,
                        },
                    },
                    {
                        loader: 'postcss-loader',
                        option: {
                            plugins: [
                                autoprefixer(),
                                pxtorem({
                                  rootValue: 75,
                                  propList: ['*'],
                                  selectorBlackList: ['html']
                                })
                              ]
                        }
                    },
                    'sass-loader'
                ]
            }
        },
        {
            mode: 'all',
            name: 'css-loader',
            loader: {
                test: /\.css/,
                loaders: [
                    mode === 'development' ? 'vue-style-loader' : {
                        loader: MiniCssExtractPlugin.loader,
                        options: {
                            reloadAll: true,
                        },
                    },
                    {
                        loader: 'css-loader',
                        options: {
                            importLoaders: 1,
                        },
                    },
                    {
                        loader: 'postcss-loader',
                        option: {
                            plugins: [
                                autoprefixer(),
                                pxtorem({
                                  rootValue: 75,
                                  propList: ['*'],
                                  selectorBlackList: ['html']
                                })
                              ]
                        }
                    }
                ]
            }

        },
        {
            mode: 'all',
            name: 'url-loader',
            loader: {
                test: /\.(png|jpg|gif)$/,
                use: [
                    {
                        loader: 'file-loader',
                        options: {
                            name: 'static/images/[name].[contenthash:8].[ext]'
                        }
                    }
                ]
            }
        },
        {
            mode: 'all',
            name: 'svg-loader',
            loader: {
                test: /\.svg/,
                use: [
                    {
                        loader: 'svg-inline-loader'
                    }
                ]
            }
        }
    ]

    const loader = all_loader.filter(l => l.mode === mode || l.mode === 'all').map(l => l.loader)

    return loader
}

module.exports = getLoader